@@ -3,7 +3,7 @@
  *  Interface to GiNaC's indexed expressions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2009 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,16 +20,15 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_INDEXED_H__
-#define __GINAC_INDEXED_H__
-
-#include <map>
+#ifndef GINAC_INDEXED_H
+#define GINAC_INDEXED_H
 
 #include "exprseq.h"
 #include "wildcard.h"
 
-namespace GiNaC {
+#include <map>
 
+namespace GiNaC {
 
 class scalar_products;
 class symmetry;
@@ -151,12 +150,16 @@ public:
 	ex imag_part() const;
 	exvector get_free_indices() const;
 
+	/** Save (a.k.a. serialize) indexed object into archive. */
+	void archive(archive_node& n) const;
+	/** Read (a.k.a. deserialize) indexed object from archive. */
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	ex derivative(const symbol & s) const;
 	ex thiscontainer(const exvector & v) const;
 	ex thiscontainer(std::auto_ptr<exvector> vp) const;
 	unsigned return_type() const;
-	tinfo_t return_type_tinfo() const { return op(0).return_type_tinfo(); }
+	return_type_t return_type_tinfo() const { return op(0).return_type_tinfo(); }
 	ex expand(unsigned options = 0) const;
 
 	// new virtual functions which can be overridden by derived classes
@@ -198,6 +201,7 @@ protected:
 protected:
 	ex symtree; /**< Index symmetry (tree of symmetry objects) */
 };
+GINAC_DECLARE_UNARCHIVER(indexed);
 
 
 class spmapkey {
@@ -281,4 +285,4 @@ ex expand_dummy_sum(const ex & e, bool subs_idx = false);
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_INDEXED_H__
+#endif // ndef GINAC_INDEXED_H
