@@ -3,7 +3,7 @@
  *  Interface to GiNaC's initially known functions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2008 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2009 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_INIFCNS_H__
-#define __GINAC_INIFCNS_H__
+#ifndef GINAC_INIFCNS_H
+#define GINAC_INIFCNS_H
 
 #include "numeric.h"
 #include "function.h"
@@ -212,4 +212,4 @@ ex convert_H_to_Li(const ex& parameterlst, const ex& arg);
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_INIFCNS_H__
+#endif // ndef GINAC_INIFCNS_H
